/**************************************************************************
**
** This file is part of libqtcontacts-telepathy
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef QTELEPATHYABSTRACTREQUEST_H_
#define QTELEPATHYABSTRACTREQUEST_H_

#include <qtcontacts.h>

#include <TelepathyQt4/Account>
#include <TelepathyQt4/PendingOperation>
#include <TelepathyQt4/PendingReady>
#include <TelepathyQt4/PendingChannel>
#include <TelepathyQt4/ContactSearchChannel>
#include <TelepathyQt4/PendingChannelRequest>
#include <TelepathyQt4/Feature>
#include <TelepathyQt4/Contact>

#include "logger.h"

QTM_USE_NAMESPACE

////////////////////////////////////////////////////////////////////////////////////////////////////

class QContactTelepathyEngine;

////////////////////////////////////////////////////////////////////////////////////////////////////

class QTelepathyAbstractRequest : public QObject
{
    Q_DISABLE_COPY(QTelepathyAbstractRequest)
    Q_OBJECT

protected:
    QTelepathyAbstractRequest(QContactTelepathyEngine *engine, QObject *parent = 0);

public:
    const QContactTelepathyEngine * engine() const { return m_engine; }
    QContactTelepathyEngine * engine() { return m_engine; }
    virtual ~QTelepathyAbstractRequest();

public:
    virtual bool start() = 0;

protected: // abstract API which must be implemented
    virtual void emitResult(QContactManager::Error error) = 0;
    virtual const QContactAbstractRequest * request() const = 0;
    virtual QContactAbstractRequest * request() = 0;

protected slots:
    virtual void emitResult();

protected: // internal attributes
    QContactManager::Error lastError() const { return m_lastError; }
    void setLastError(QContactManager::Error error) { m_lastError = error; }

protected: // internal methods
    const QctLogger & qctLogger() const { return m_logger; }
    void reportError(const QString &message, QContactManager::Error error = QContactManager::UnspecifiedError);

private:
    static QString makePrefix(QContactTelepathyEngine *engine);

private: // fields
    QContactTelepathyEngine *const m_engine;
    QctLogger m_logger;
    QContactManager::Error m_lastError;
};

#endif /* QTELEPATHYABSTRACTREQUEST_H_ */
