/**************************************************************************
**
** This file is part of libqtcontacts-telepathy
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef QTELEPATHYCONTACTENGINE_H
#define QTELEPATHYCONTACTENGINE_H

#include <QObject>
#include <qtcontacts.h>
#include <QContactManagerEngine>

QTM_USE_NAMESPACE

////////////////////////////////////////////////////////////////////////////////////////////////////

class QContactTelepathyEngineData;
class QContactTelepathyEngine : public QContactManagerEngine
{
    Q_OBJECT

public:
    enum DebugFlag {
        ShowNotes = (1 << 0),
        ShowTiming = (1 << 1),
        ShowSignals = (1 << 2)
    };

    Q_DECLARE_FLAGS(DebugFlags, DebugFlag)

    QContactTelepathyEngine(const QMap<QString, QString>& parameters,
                          const QString& managerName = QLatin1String("telepathy"),
                          int managerVersion = 1);
    ~QContactTelepathyEngine();

    QContactTelepathyEngine(const QContactTelepathyEngine& other);
    QContactTelepathyEngine& operator=(const QContactTelepathyEngine& other);

    /* Definitions - Accessors and Mutators */
    QMap<QString, QContactDetailDefinition> detailDefinitions(const QString& contactType, QContactManager::Error* error) const;

    /* Asynchronous Request Support */
    void requestDestroyed(QContactAbstractRequest* req);
    bool startRequest(QContactAbstractRequest* req);
    bool cancelRequest(QContactAbstractRequest *request);

    /* Capabilities reporting */
    QString managerName() const;
    int managerVersion() const;

    bool hasFeature(QContactManager::ManagerFeature feature, const QString& contactType) const;
    bool isFilterSupported(const QContactFilter& filter) const;
    QList<QVariant::Type> supportedDataTypes() const;
    QStringList supportedContactTypes() const;

    QContact compatibleContact(const QContact&, QContactManager::Error* error) const;
    bool validateContact(const QContact&, QContactManager::Error* error) const;
    bool validateDefinition(const QContactDetailDefinition&, QContactManager::Error* error) const;
    bool saveDetailDefinition(const QContactDetailDefinition&, const QString&, QContactManager::Error* error);
    bool removeDetailDefinition(const QString&, const QString&, QContactManager::Error* error);

public: // custom attributes
    const DebugFlags & debugFlags() const;
    bool hasDebugFlag(DebugFlag flag) const;
    QString accountPath() const;

private slots:
    void onRequestDestroyed(QObject *obj = 0);

private:
    void init();

private:
    QExplicitlySharedDataPointer<QContactTelepathyEngineData> d;
};

////////////////////////////////////////////////////////////////////////////////////////////////////

Q_DECLARE_OPERATORS_FOR_FLAGS(QContactTelepathyEngine::DebugFlags);

////////////////////////////////////////////////////////////////////////////////////////////////////

#endif // QTELEPATHYCONTACTENGINE_H
