/**************************************************************************
**
** This file is part of libqtcontacts-telepathy
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef QTELEPATHYCONTACTENGINE_P_H
#define QTELEPATHYCONTACTENGINE_P_H

#include <QtCore>

#include "abstractrequest.h"
#include "engine.h"

class QContactTelepathyEngineData : public QSharedData
{
    // Using void pointer for the key since it might point onto an already destructed object.
    typedef QList<QTelepathyAbstractRequest*> RequestList;
    typedef QMap<QString, QString> ParameterMap;

public:
    typedef QMap<void*, QTelepathyAbstractRequest*> RequestMap;

public:
    explicit QContactTelepathyEngineData(const ParameterMap & parameters,
                                       const QString & engineName,
                                       int engineVersion);
    QContactTelepathyEngineData(const QContactTelepathyEngineData & other);
    ~QContactTelepathyEngineData();

    static ParameterMap readEnvironment();

private:
    void parseParameters();

public: // parameters
    QString m_engineName;
    int m_engineVersion;

    ParameterMap m_parameters;
    mutable QScopedPointer<ParameterMap> m_managerParameters;
    QContactTelepathyEngine::DebugFlags m_debugFlags;
    QString m_accountPath;

public:
    uint m_selfContactId;

public: // state
    mutable RequestMap m_requests;
    QMutex m_mutex;
};

#endif // QTELEPATHYCONTACTENGINE_P_H
