/**************************************************************************
**
** This file is part of libqtcontacts-telepathy
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef TELEPATHY2QCONTACTCONVERTOR_H_
#define TELEPATHY2QCONTACTCONVERTOR_H_

#include <QContact>
#include <QContactManager>
#include <QContactFilter>
#include <QContactLocalIdFilter>

#include "abstractrequest.h"


QTM_BEGIN_NAMESPACE

class QContactManagerEngine;
QTM_END_NAMESPACE

QTM_USE_NAMESPACE

///////////////////////////////////////////////////////////////////////////////

/* first - accountPath, second - contactId */
typedef QPair <QString, QString> TelepathyContactId;
typedef QHashIterator<Tp::ContactPtr, Tp::Contact::InfoFields> TelepathyContacts;

///////////////////////////////////////////////////////////////////////////////


class Telepathy2QContactConvertor
{
public:
    static bool                            convertTelepathyContacts2QContacts(const TelepathyContacts &input, QList<QContact> &output, const QString &accountPath, const QContactManagerEngine * const engine);
    static QList< TelepathyContactId >     contactId2TelepathyIds(QContactLocalId contactId);
    static QContactLocalId                 telepathyId2ContactId(const TelepathyContactId &id);
    static QContactPresence::PresenceState presenceConversion(const Tp::ConnectionPresenceType &presenceType);
    static void                            contactFieldConversionAppendToContact(const Tp::ContactInfoField &field, QContact &contact);
    static QString                         contactFieldContextConversion(const Tp::ContactInfoField &field);

private:
    static QMultiHash<QContactLocalId, TelepathyContactId > m_contactId2TelepathyId;
    /* stringified telepathy id to multiple QContactLocalId mapping */
    static QMultiHash<QString, QContactLocalId>             m_telepathyId2ContactId;
};

#endif /* TELEPATHY2QCONTACTCONVERTOR_H_ */
