/**************************************************************************
**
** This file is part of libqtcontacts-telepathy
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#include "factory.h"

#include <engine/engine.h>

QContactManagerEngine* ContactTelepathyFactory::engine(const QMap<QString, QString>& parameters,
                                                     QContactManager::Error* error)
{
    qDebug(PACKAGE ": initializing " PACKAGE " " VERSION);

    if (error) {
        *error = QContactManager::NoError;
    }

    static const int version = ((VERSION_MAJOR) * 100 + VERSION_MINOR) * 100 + VERSION_MICRO;
    QContactTelepathyEngine *p = new QContactTelepathyEngine(parameters, managerName(), version);

    m_engines.append (QPointer<QContactManagerEngine>(p));

    return p;
}

QString ContactTelepathyFactory::managerName() const
{
    return QLatin1String("telepathy");
}

ContactTelepathyFactory::~ContactTelepathyFactory()
{
    foreach (QPointer<QContactManagerEngine> p, m_engines) {
        delete p.data();
    }
}

Q_EXPORT_PLUGIN2(qtcontacts_telepathy, ContactTelepathyFactory);
