/**************************************************************************
**
** This file is part of libqtcontacts-telepathy
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef QTELEPATHYCONTACTFETCHREQUEST_H
#define QTELEPATHYCONTACTFETCHREQUEST_H

#include <QObject>
#include <qtcontacts.h>

#include <TelepathyQt4/Account>
#include <TelepathyQt4/PendingOperation>
#include <TelepathyQt4/PendingReady>
#include <TelepathyQt4/PendingChannel>
#include <TelepathyQt4/ContactSearchChannel>
#include <TelepathyQt4/PendingChannelRequest>
#include <TelepathyQt4/Feature>
#include <TelepathyQt4/Contact>
#include <TelepathyQt4/AccountManager>

/*!
 * \class QCTToolClient
 * \brief Used for utility tool qct-tool to list accounts and contacts.
**/
class QCTToolClient : public QObject
{
    Q_OBJECT

public:
    void search(const QString &accountPath, const QString &searchPattern);
    void listAccounts();

private slots:
    void getChannel();
    void gotChannel(Tp::PendingOperation*);
    void onChannelReady(Tp::PendingOperation *op);
    void onSearchStateChanged(Tp::ChannelContactSearchState ,const QString &,
                          const Tp::ContactSearchChannel::SearchStateChangeDetails &);

    void onSearchResultReceived(const Tp::ContactSearchChannel::SearchResult&);
    void onAccountManagerReady(Tp::PendingOperation *op);

private: // fields
    Tp::ChannelPtr                      m_channel;
    Tp::ContactSearchChannelPtr         m_contactSearchChannel;
    Tp::PendingOperation*               m_searchOperation;
    Tp::AccountPtr                      m_account;
    Tp::AccountManagerPtr               m_accountManager;
    QString                             m_searchPattern;
    QString                             m_accountPath;
};

////////////////////////////////////////////////////////////////////////////////////////////////////

#endif // QTELEPATHYCONTACTFETCHREQUEST_H
